const EOL = require('os').EOL;
const path = require('path');
const fs = require('fs');

/* eslint-env node */
module.exports = {
  description: '',

  normalizeEntityName() {}, // no argument
  
  // locals(options) {
  //   // Return custom template variables here.
  //   return {
  //     foo: options.entity.options.foo
  //   };
  // }
  fileMapTokens(options) {
    return {
      __root__() {
        if (options.inDummy) {
          return 'tests/dummy/app';
        } else {
          return 'app';
        } 
      },
      __mirage__() { return '../mirage'}
    }
  },

  afterInstall(options) {
    // Perform extra work here.
    // Add proxy check to config/environment.js 
    let configPath = (options.dummy) ? "tests/dummy/config/environment.js" : "config/environment.js";

    let proxy = "\nfunction usingProxy() {\n"+
                    "\tvar usingProxyArg = !!process.argv.filter(function (arg) {\n"+
                    "\t\treturn arg.indexOf('--proxy') === 0 || arg.indexOf('-pr') === 0 || arg.indexOf('-pxy') === 0;\n"+
                    "\t}).length;\n\n"+
                    "\tvar hasGeneratedProxies = false;\n"+
                    "\tvar proxiesDir = process.env.PWD + '/server/proxies';\n"+
                    "\ttry {\n"+
                    "\t\tfs.lstatSync(proxiesDir);\n"+
                    "\t\thasGeneratedProxies = true;\n"+
                    "\t} catch (e) {}\n\n"+    
                    "\treturn usingProxyArg || hasGeneratedProxies;\n}\n";
    addLineToFile(this, configPath, /'use strict';/, proxy);
    addLineToFile(this, configPath, /when it is created/, "\t\tproxy: usingProxy(),");

    // Add import of ember_aws_ehipster.css to apps.css
    let stylePath = (options.dummy) ? "tests/dummy/app/styles/app.css" : "app/styles/app.css";
    let importcss = "@import 'ember-aws-ehipster.css';\n";
    let fileContents = importcss + fs.readFileSync(stylePath, 'utf-8');
    fs.writeFileSync(stylePath, fileContents, 'utf-8');

    // Add master path for dealing with entities  
    let routerPath = (options.dummy) ? "tests/dummy/app/router.js" : "app/router.js";
    let routerLine = "\tthis.route('entity-factory', function() {\n\t});\n";
    addLineToFile(this, routerPath, /Router\.map\(function\(\) {/, routerLine);

  }
};

function addLineToFile(ctx, filePath, markerString, addedLine) {
  let fileContents = fs.readFileSync(filePath, 'utf-8');

  if (fileContents.indexOf(addedLine) === -1) {
   //ctx.ui.writeLine("\tAdd line "+addedLine+" to file "+filePath);
   fileContents = fileContents.replace(markerString, [
     '$&',
     addedLine,
   ].join('\n'));
 }
 if (fileContents.indexOf(addedLine) === -1) {
   ctx.ui.writeWarnLine(
     'Unable to update '+filePath+'. You should update this file manually.');
 } else {
   fs.writeFileSync(filePath, fileContents, 'utf-8');
 }
}
